@@ -1,3 +1,4 @@
+gchar *s = N_("Accordion")
 gchar *s = N_("Agnes")
 gchar *s = N_("Athena")
 gchar *s = N_("Auld Lang Syne")
@@ -25,6 +26,7 @@ gchar *s = N_("Escalator")
 gchar *s = N_("First Law")
 gchar *s = N_("Fortress")
 gchar *s = N_("Fortunes")
+gchar *s = N_("Forty Thieves")
 gchar *s = N_("Fourteen")
 gchar *s = N_("Freecell")
 gchar *s = N_("Gaps")
@@ -42,6 +44,7 @@ gchar *s = N_("Kansas")
 gchar *s = N_("King Albert")
 gchar *s = N_("Kings Audience")
 gchar *s = N_("Klondike")
+gchar *s = N_("Klondike Three Decks")
 gchar *s = N_("Labyrinth")
 gchar *s = N_("Lady Jane")
 gchar *s = N_("Maze")
@@ -68,6 +71,7 @@ gchar *s = N_("Straight Up")
 gchar *s = N_("Streets And Alleys")
 gchar *s = N_("Template")
 gchar *s = N_("Ten Across")
+gchar *s = N_("Terrace")
 gchar *s = N_("Thieves")
 gchar *s = N_("Thirteen")
 gchar *s = N_("Thumb And Pouch")
