@@ -65,7 +65,9 @@ extern int rot_next;
 
 extern bool random_block_colors;
 
+#ifndef HAVE_CLUTTER
 class Field;
+#endif
 class Preview;
 class BlockOps;
 class ScoreFrame;
@@ -93,9 +95,12 @@ private:
 	char *defaultPixmap;
 	gint themeno;
 
+#ifdef HAVE_CLUTTER
+	BlockOps *field;
+#else
 	Field *field;
+#endif
 	Preview *preview;
-	BlockOps *ops;
 	ScoreFrame *scoreFrame;
 	HighScores *high_scores;
 
