@@ -72,6 +72,9 @@ gint configure_event (GtkWidget * widget, GdkEventConfigure * event);
 gint button_press_event (GtkWidget * widget, GdkEventButton * event);
 void gui_draw_pixmap (gint which, gint x, gint y);
 void gui_draw_pixmap_buffer (gint which, gint x, gint y);
+void set_animation_speed (gint speed);
+void start_animation (void);
+void stop_animation (void);
 gint flip_pixmaps (gpointer data);
 void init_new_game (void);
 void clear_board (void);
