@@ -4,7 +4,7 @@
  * Project: GGZ GTK Games
  * Date: 10/13/2002 (moved from GGZCards)
  * Desc: Create the "Players" Gtk dialog
- * $Id: games-dlg-players.c 8202 2008-10-26 14:45:52Z chpe $
+ * $Id: games-dlg-players.c 8697 2009-02-10 00:42:33Z thomashpa $
  *
  * Copyright (C) 2002 GGZ Development Team
  *
@@ -109,11 +109,11 @@ update_player_list (GtkWidget * tree)
     GGZSeat seat = ggzmod_get_seat (ggz, p);
     GtkTreeIter iter;
     const gchar *status = NULL, *name = NULL;
-    gchar num[32];
+    gchar numstr[32];
 
     gtk_list_store_append (store, &iter);
 
-    snprintf (num, sizeof (num), "%d", p);
+    snprintf (numstr, sizeof (numstr), "%d", p);
     switch (seat.type) {
     case GGZ_SEAT_PLAYER:
       status = _("Occupied");
@@ -139,10 +139,12 @@ update_player_list (GtkWidget * tree)
       status = _("-");
       name = seat.name;
       break;
+    default:
+      g_assert_not_reached ();
     }
 
     gtk_list_store_set (store, &iter,
-			PLAYER_COLUMN_SEAT, num,
+			PLAYER_COLUMN_SEAT, numstr,
 			PLAYER_COLUMN_ISSPECTATOR,
 			(gboolean) FALSE, PLAYER_COLUMN_SEATNUM,
 			(gint) p, PLAYER_COLUMN_TYPE, status,
@@ -191,7 +193,7 @@ create_player_list (void)
   GtkWidget *tree;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
-  GtkTreeSelection *select;
+  GtkTreeSelection *selection;
 
   assert (PLAYER_COLUMNS == 5);
   store = gtk_list_store_new (PLAYER_COLUMNS,
@@ -224,8 +226,8 @@ create_player_list (void)
 					      PLAYER_COLUMN_NAME, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 
-  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
-  gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
+  gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
   /* FIXME:  This feature is not supported by gnome-games yet. 
    * g_signal_connect(tree, "button-press-event",
@@ -275,13 +277,6 @@ create_dlg_players (GtkWindow * parent)
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
   gtk_widget_show (vbox);
 
-#if 0
-  label = gtk_label_new (_("List of players:"));
-  gtk_widget_ref (label);
-  gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-#endif
-
   tree = create_player_list ();
   g_object_ref_sink(tree);
   g_object_set_data_full (G_OBJECT (dialog), "tree", tree,
