@@ -50,16 +50,10 @@ gint board_sizes[MAX_SIZE][3] = { {-1, -1, -1}
 {45, 30, 4}
 };
 
-const GamesScoresCategory scorecats[] = { {"Small", N_("Small")},
-{"Medium", N_("same-gnome|Medium")},
-{"Large", N_("Large")},
-GAMES_SCORES_LAST_CATEGORY
-};
-
-static const GamesScoresDescription scoredesc = { scorecats,
-  "Small",
-  "same-gnome",
-  GAMES_SCORES_STYLE_PLAIN_DESCENDING
+const GamesScoresCategory scorecats[] = {
+  { "Small",  NC_("board size", "Small") },
+  { "Medium", NC_("board size", "Medium") },
+  { "Large",  NC_("board size", "Large") }
 };
 
 GamesScores *highscores;
@@ -141,23 +135,11 @@ main (int argc, char *argv[])
   gboolean retval;
   GError *error = NULL;
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
-
   if (!games_runtime_init ("same-gnome"))
     return 1;
 
   setgid_io_init ();
 
-  /* Initialise i18n. */
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
@@ -180,7 +162,11 @@ main (int argc, char *argv[])
 
   games_stock_init ();
 
-  highscores = games_scores_new (&scoredesc);
+  highscores = games_scores_new ("same-gnome",
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 "board size", NULL,
+                                 0 /* default category */,
+                                 GAMES_SCORES_STYLE_PLAIN_DESCENDING);
 
   initialise_options (requested_size, requested_theme);
 
